/**
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import { CfnAgent } from 'aws-cdk-lib/aws-bedrock';
/**
 * Properties for SessionSummaryConfiguration.
 */
export interface SessionSummaryMemoryProps {
    /**
     * Duration in days for which session summaries are retained (1-365)
     * @default 30
     */
    readonly memoryDurationDays?: number;
    /**
     * Maximum number of recent session summaries to include (min 1)
     * @default 20
     */
    readonly maxRecentSessions?: number;
}
/**
 * Memory class for managing Bedrock Agent memory configurations. Enables conversational context retention
 * across multiple sessions through session identifiers. Memory context is stored with unique
 * memory IDs per user, allowing access to conversation history and summaries. Supports viewing
 * stored sessions and clearing memory.
 *
 * @see https://docs.aws.amazon.com/bedrock/latest/userguide/agents-memory.html
 */
export declare class Memory {
    /**
     * Returns session summary memory with default configuration.
     * @default memoryDurationDays=30, maxRecentSessions=20
     */
    static readonly SESSION_SUMMARY: CfnAgent.MemoryConfigurationProperty;
    /**
     * Creates a session summary memory with custom configuration.
     * @param props Optional memory configuration properties
     * @returns Memory configuration object
     */
    static sessionSummary(props: SessionSummaryMemoryProps): CfnAgent.MemoryConfigurationProperty;
    /**
     * Validate at synth time the configuration.
     */
    private static validateSessionSummaryMemoryProps;
}
