/**
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
export { KnowledgeBaseBase } from './knowledge-base';
import * as iam from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
import { CommonKnowledgeBaseAttributes, CommonKnowledgeBaseProps, IKnowledgeBase, KnowledgeBaseBase, KnowledgeBaseType } from './knowledge-base';
import { IKendraGenAiIndex } from '../../kendra';
/******************************************************************************
 *                             COMMON INTERFACES
 *****************************************************************************/
export interface IKendraKnowledgeBase extends IKnowledgeBase {
    /**
     * The GenAI Kendra Index.
     */
    readonly kendraIndex: IKendraGenAiIndex;
}
/******************************************************************************
 *                        PROPS FOR NEW CONSTRUCT
 *****************************************************************************/
/**
 * Properties for creating a Kendra Index Knowledge Base.
 */
export interface KendraKnowledgeBaseProps extends CommonKnowledgeBaseProps {
    /**
     * The Kendra Index to use for the knowledge base.
     */
    readonly kendraIndex: IKendraGenAiIndex;
}
/******************************************************************************
 *                      ATTRS FOR IMPORTED CONSTRUCT
 *****************************************************************************/
/**
 * Properties for importing a knowledge base outside of this stack
 */
export interface KendraKnowledgeBaseAttributes extends CommonKnowledgeBaseAttributes {
    /**
     * The GenAI Kendra Index ARN.
     */
    readonly kendraIndex: IKendraGenAiIndex;
}
/******************************************************************************
 *                              ABSTRACT CLASS
 *****************************************************************************/
export declare abstract class KendraKnowledgeBaseBase extends KnowledgeBaseBase {
    abstract readonly knowledgeBaseArn: string;
    abstract readonly knowledgeBaseId: string;
    abstract readonly role: iam.IRole;
    abstract readonly kendraIndex: IKendraGenAiIndex;
    abstract readonly description?: string;
    abstract readonly instruction?: string;
    readonly type: KnowledgeBaseType;
}
/******************************************************************************
 *                        		  CONSTRUCT
 *****************************************************************************/
export declare class KendraKnowledgeBase extends KendraKnowledgeBaseBase {
    static fromKnowledgeBaseAttributes(scope: Construct, id: string, attrs: KendraKnowledgeBaseAttributes): IKendraKnowledgeBase;
    readonly knowledgeBaseArn: string;
    readonly knowledgeBaseId: string;
    readonly role: iam.IRole;
    readonly description?: string;
    readonly instruction?: string;
    /**
     * The name of the knowledge base.
     */
    readonly name: string;
    /**
     * The GenAI Kendra Index.
     */
    readonly kendraIndex: IKendraGenAiIndex;
    /**
     * The type of Knowledge Base
     */
    readonly type: KnowledgeBaseType;
    private readonly _resource;
    constructor(scope: Construct, id: string, props: KendraKnowledgeBaseProps);
}
